#
# spec file for package python-proliantutils
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           python-proliantutils
Version:        2.8.2
Release:        6.1
Summary:        Client Library for interfacing with various devices in HP Proliant Servers
License:        Apache-2.0
Group:          Development/Languages/Python
Url:            https://github.com/openstack/proliantutils
Source:         https://files.pythonhosted.org/packages/source/p/proliantutils/proliantutils-%{version}.tar.gz
BuildRequires:  fdupes
BuildRequires:  openstack-macros
BuildRequires:  python-ddt
BuildRequires:  python-devel
BuildRequires:  python-jsonschema
BuildRequires:  python-mock
BuildRequires:  python-os-testr
BuildRequires:  python-oslo.concurrency
BuildRequires:  python-oslo.serialization
BuildRequires:  python-oslo.utils
BuildRequires:  python-pbr
BuildRequires:  python-pysnmp
BuildRequires:  python-requests
BuildRequires:  python-retrying
BuildRequires:  python-rpm-macros
BuildRequires:  python-setuptools
BuildRequires:  python-six
BuildRequires:  python-sushy
BuildRequires:  python-testrepository
BuildRequires:  python-testtools
Requires:       python-jsonschema >= 2.0.0
Requires:       python-oslo.concurrency >= 3.8.0
Requires:       python-oslo.serialization >= 1.10.0
Requires:       python-oslo.utils >= 3.20.0
Requires:       python-pysnmp >= 4.2.3
Requires:       python-requests >= 2.10.0
Requires:       python-retrying >= 1.2.3
Requires:       python-six >= 1.9.0
Requires:       python-sushy >= 1.8.0
BuildArch:      noarch

%description
proliantutils is a set of utility libraries for interfacing and managing
various components (like iLO, HPSSA) for HP Proliant Servers.  This library
is used by iLO drivers in Ironic for managing Proliant Servers, though the
library can be used by anyone who wants to manage HP Proliant servers.

Please use https://bugs.launchpad.net/proliantutils to report bugs and ask
questions.

%prep
%setup -q -n proliantutils-%{version}

%build
%py2_build

%install
%py2_install
%fdupes %{buildroot}%{python_sitelib}

%check
%{__python2} setup.py testr

%files
%doc README.rst
%license LICENSE
%{python_sitelib}/*

%changelog
* Wed Mar  6 2019 dmueller@suse.com
- update to 2.8.2:
  * Adding changes to support sushy virtual media
  * Revert "Add NIC inspection for Gen9"
  * Added support for IPv6 network
  * Inband disk erase support for SSD disk drives
  * Add NIC inspection for Gen9
  * Use Sushy caching decorators
  * Adds changes in hpssa validator to support '10','50,'60' raid level
  * Change impending version to 2.7.0 (and not 2.6.1)
  * Update ChangeLog for proliantutils release 2.6.1
  * Adds API to get the results of the BIOS settings
  * Follow-up for commit 0e9f3d1b4620b0ad9ff6370132ba5a8d5f3cc21e
  * Validates the BIOS settings before applying
  * Redfish: Adds 'read\_raid\_configuration' API to get current raid config
  * Fix ssacli output parsing. New untitest for the fixed issue added
  * Redfish: Adds \`create\_raid\_configuration\` API to create raid
* Thu Feb 28 2019 dmueller@suse.com
- update to 2.6.0:
  * iLO Redfish: Adds support to manage BIOS settings
  * Redfish: Adds 'delete\_raid\_configuration' API to clear raid
  * iLO RIS: Add support to manage BIOS settings
  * Add support for retrieving system POST state
  * Add support for NMI(Non Maskable Interrupt)
  * Exclude pysnmp\_mibs from search path
  * Make case-insensitive search for Blade server model string
  * Using assertIsNone() instead of assertEqual(None)
  * Fixes session issue for Gen10 servers
  * Minor fix in test case
- remove 60910b9257c70211445086af2ea014327a03f80a.patch (upstream)
* Wed Apr 25 2018 tbechtold@suse.com
- use fdupes to reduce rpm-lint warnings
* Thu Apr 19 2018 tbechtold@suse.com
- update to 2.5.1:
  * Updated ChangeLog for proliantutils release 2.5.1
    Also updated the AUTHORS file
  * Remove the disk erase timeout
  * Fixes secure\_boot capability
- add 60910b9257c70211445086af2ea014327a03f80a.patch
  This fixes a testcase
* Fri Feb 23 2018 tbechtold@suse.com
- update to 2.5.0:
  * Updated ChangeLog for proliantutils 2.5.0 release
  * Retain "mac" argument for backward compatibility
  * Changes to support Sushy 1.3.0
  * Redfish: Adding the ability to get and set iSCSI initiator
  * Redfish: Adding the ability to set and unset iSCSI boot info
  * Redfish: Changed 'update\_persistent\_boot' to set 'UefiTarget' boot device.
    Also removed 'mac' from 'set\_one\_time\_boot'
  * Remove 'mac' argument for [un]set\_iscsi\_boot\_info()
  * Changed '\_update\_persistent\_boot' to set 'UefiTarget' boot device
    also removed 'mac' from 'set\_one\_time\_boot'
  * Add support to set iSCSI initiator information
  * Retry power on operation for Blade servers
  * Updates 'set\_one\_time\_boot' to accept MAC address
  * Add support to get iscsi initiator information
* Thu Feb  8 2018 tbechtold@suse.com
- Build only for python2
- Enable unittests in %%check
* Thu Feb  8 2018 tbechtold@suse.com
- Add missing Requires and BuildRequires
* Thu Feb  1 2018 jengelh@inai.de
- Drop markup from plaintext description.
* Wed Jan 31 2018 dmueller@suse.com
- Initial package (2.4.1)
